<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#037ef3';
	$secondary_color = '#2c9f45';
	$footer_bg_color ="#4d626e";

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$loop_style_choices = array(
		'choice-1' => 'Grid Layout',
		'choice-2' => 'Loop Layout',
	);	

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'subscribe-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Default Logo', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	

	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Theme Primary Color', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['secondary-color'] = array(
		'id' => 'secondary-color',
		'label'   => __( 'Theme Secondary Color', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color // hex
	);

	$options['footerbg-bg-color'] = array(
		'id' => 'footer-bg-color',
		'label'   => __( 'Footer Background Color', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $footer_bg_color // hex
	);

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Source Sans Pro'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Source Sans Pro'
	);	

	$options['body-font-size'] = array(
		'id' => 'body-font-size',
		'label'   => __( 'Body Font Size (in px)', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '17',		
	);

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);				

	$options['transparent-header-on'] = array(
		'id' => 'transparent-header-on',
		'label'   => __( 'Transparent site header ', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);		
	
	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['header-cart-on'] = array(
		'id' => 'header-cart-on',
		'label'   => __( 'Display cart menu on header', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['projects-page-title'] = array(
		'id' => 'projects-page-title',
		'label'   => __( 'Projects Page Title', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Our Work',		
	);	

	$options['services-page-title'] = array(
		'id' => 'services-page-title',
		'label'   => __( 'Services Page Title', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Our Services',		
	);

	$options['employees-page-title'] = array(
		'id' => 'employees-page-title',
		'label'   => __( 'Employees Page Title', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Meet Our Team',		
	);

	$options['blog-page-title'] = array(
		'id' => 'blog-page-title',
		'label'   => __( 'Blog Page Title', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'News from Our Blog',		
	);	

	$options['loop-style'] = array(
		'id' => 'loop-style',
		'label'   => __( 'Latest Posts Style', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $loop_style_choices,
		'default' => 'choice-1'
	);	

	$options['loop-excerpt-length'] = array(
		'id' => 'loop-excerpt-length',
		'label'   => __( 'Post excerpt length - Blog Layout', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '70',		
	);

	$options['grid-excerpt-length'] = array(
		'id' => 'grid-excerpt-length',
		'label'   => __( 'Post excerpt length - Grid Layout', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '38',		
	);	

	$options['employee-excerpt-length'] = array(
		'id' => 'employee-excerpt-length',
		'label'   => __( 'Employee excerpt length', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '20',		
	);		

	$options['full-project-on'] = array(
		'id' => 'full-project-on',
		'label'   => __( 'Make single project page full width', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);

	$options['single-breadcrumbs-on'] = array(
		'id' => 'single-breadcrumbs-on',
		'label'   => __( 'Display breadcrumbs on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Display featured image on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['single-newsletter-on'] = array(
		'id' => 'single-newsletter-on',
		'label'   => __( 'Display newsletter form on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'subscribe-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);			

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'subscribe-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );