<?php
/**
 * Pricing tables widget
 *
 * @package subscribe
 */

class subscribe_Pricing_Tables_Widget extends WP_Widget {

	public function __construct() {
		$widget_ops = array('classname' => 'subscribe_pricing_widget', 'description' => __( 'Show what plans you are able to provide.', 'subscribe-pro') );
        parent::__construct(false, $name = __('Home - Pricing Tables', 'subscribe-pro'), $widget_ops);
		$this->alt_option_name = 'subscribe_pricing_widget';
			
    }
	
	function form($instance) {
		$title     		= isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    		= isset( $instance['number'] ) ? intval( $instance['number'] ) : -1;
		$category   	= isset( $instance['category'] ) ? esc_attr( $instance['category'] ) : '';
		$see_all   		= isset( $instance['see_all'] ) ? esc_url( $instance['see_all'] ) : '';		
		$see_all_text  	= isset( $instance['see_all_text'] ) ? esc_html( $instance['see_all_text'] ) : '';
		$cols 			= isset( $instance['cols'] ) ? esc_attr( $instance['cols'] ) : '';
    	$newtab   		= isset( $instance['newtab'] ) ? (bool) $instance['newtab'] : false;

	?>

	<p><?php _e('In order to display this widget, you must first add some pricing tables from your admin area.', 'subscribe-pro'); ?></p>
	<p>
	<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'subscribe-pro'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
	</p>
	<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of pricing tables to show (-1 shows all of them):', 'subscribe-pro' ); ?></label>
	<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
    <p><label for="<?php echo $this->get_field_id('see_all'); ?>"><?php _e('The URL for your button [In case you want a button below your pricing tables block]', 'subscribe-pro'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id( 'see_all' ); ?>" name="<?php echo $this->get_field_name( 'see_all' ); ?>" type="text" value="<?php echo $see_all; ?>" size="3" /></p>	
    <p><label for="<?php echo $this->get_field_id('see_all_text'); ?>"><?php _e('The text for the button [Defaults to <em>See all our plans</em> if left empty]', 'subscribe-pro'); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id( 'see_all_text' ); ?>" name="<?php echo $this->get_field_name( 'see_all_text' ); ?>" type="text" value="<?php echo $see_all_text; ?>" size="3" /></p>
	<p><label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Enter the slug for your category or leave empty to show all pricing tables.', 'subscribe-pro' ); ?></label>
	<input class="widefat" id="<?php echo $this->get_field_id( 'category' ); ?>" name="<?php echo $this->get_field_name( 'category' ); ?>" type="text" value="<?php echo $category; ?>" size="3" /></p>
	<p>
	<label for="<?php echo $this->get_field_id('cols'); ?>"><?php _e( 'Number of columns:', 'subscribe-pro' ); ?></label>
	<select name="<?php echo $this->get_field_name('cols'); ?>" id="<?php echo $this->get_field_id('cols'); ?>" class="widefat">
	<?php
	$options = array('2', '3', '4');
	foreach ($options as $option) {
	echo '<option value="' . $option . '" id="' . $option . '"', $cols == $option ? ' selected="selected"' : '', '>', esc_attr($option), '</option>';
	}
	?>
	</select>
	</p>
	<p><input class="checkbox" type="checkbox" <?php checked( $newtab ); ?> id="<?php echo $this->get_field_id( 'newtab' ); ?>" name="<?php echo $this->get_field_name( 'newtab' ); ?>" />
   	<label for="<?php echo $this->get_field_id( 'newtab' ); ?>"><?php _e( 'Open button links in a new tab?', 'subscribe-pro' ); ?></label></p>    
	<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] 			= sanitize_text_field($new_instance['title']);
		$instance['number'] 		= sanitize_text_field($new_instance['number']);
		$instance['see_all'] 		= esc_url_raw( $new_instance['see_all'] );	
		$instance['see_all_text'] 	= sanitize_text_field($new_instance['see_all_text']);
		$instance['category'] 		= sanitize_text_field($new_instance['category']);
		$instance['cols'] 			= strip_tags($new_instance['cols']);
		$instance['newtab']    = is_null( $new_instance['newtab'] ) ? 0 : 1;		
		return $instance;
	}
	
	function widget($args, $instance) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title 			= ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';
		$title 			= apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$see_all 		= isset( $instance['see_all'] ) ? esc_url($instance['see_all']) : '';
		$see_all_text 	= isset( $instance['see_all_text'] ) ? esc_html($instance['see_all_text']) : '';		
		$number 		= ( ! empty( $instance['number'] ) ) ? intval( $instance['number'] ) : -1;
		if ( ! $number )
			$number 	= -1;				
		$category 		= isset( $instance['category'] ) ? esc_attr($instance['category']) : '';
		$cols 			= isset( $instance['cols'] ) ? esc_attr($instance['cols']) : '';
    	$newtab	   = isset( $instance['newtab'] ) ? $instance['newtab'] : false;

    	if ( $newtab ) {
    		$target = '_blank';
    	} else {
    		$target = '_self';
    	}

		$plans = new WP_Query( array(
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'post_type' 		  => 'pricing_tables',
			'posts_per_page'	  => $number,
			'category_name'		  => $category			
		) );

		if ( $cols == '2' ) {
			$cols_no = 'ht_grid ht_grid_1_2';
		} elseif ( $cols == '3' ) {
			$cols_no = 'ht_grid ht_grid_1_3';
		} elseif ( $cols == '4' ) {
			$cols_no = 'ht_grid ht_grid_1_4';
		} else {
			$cols_no = 'ht_grid ht_grid_1_3';
		}
		echo $args['before_widget'];

		if ($plans->have_posts()) :
?>
			<?php if ( $title ) echo $args['before_title'] . $title . $args['after_title']; ?>

			<div class="pricing-section">
				<?php while ( $plans->have_posts() ) : $plans->the_post(); ?>
					<?php global $post; ?>
					<?php $features = get_post_meta($post->ID, '_subscribe_pricing_key', true); ?>
					<?php $price = get_post_meta( $post->ID, '_subscribe_pricing_price_key', true ); ?>
					<?php $text = get_post_meta( $post->ID, '_subscribe_pricing_text_key', true ); ?>
					<?php $link = get_post_meta( $post->ID, '_subscribe_pricing_link_key', true );	?>					
					<?php $icon = get_post_meta( $post->ID, '_subscribe_pricing_icon', true );	?>					
					<?php $featured = get_post_meta( $post->ID, '_subscribe_pricing_featured', true );	?>					
					<?php if ( $featured ) {
						$plan_type = 'featured-plan';
					} else {
						$plan_type = 'normal-plan';
					} ?>

					<div class="subscribe-pricing-table <?php echo $cols_no; ?>">
						<div class="plan-item <?php echo $plan_type; ?>">
							<?php if ($icon != null) { ?>
							<div class="plan-icon">
								<i class="fa <?php echo esc_html($icon); ?>"></i>
							</div>
							<?php } ?>
							<h4><?php the_title(); ?></h4>
							<div class="plan-price">
								<?php echo wp_kses_post($price); ?>
							</div>							
							<div class="plan-text">
								<?php if ( is_array($features) ) : ?>
									<?php foreach ( $features as $feature ) : ?>
									<div class="plan-feature"><?php echo esc_html($feature['name']); ?></div>
									<?php endforeach; ?>
								<?php endif; ?>
							</div>
							<?php if ( $link ) : ?>
							<div class="plan-btn">
								<a target="<?php echo $target; ?>" class="roll-button button" href="<?php echo esc_url($link); ?>"><?php echo esc_html($text); ?></a>
							</div>
							<?php endif; ?>	
						</div>
					</div>

				<?php endwhile; ?>

			</div>	
					
			<?php if ($see_all != '') : ?>
			<a href="<?php echo esc_url($see_all); ?>" class="more-button">
				<?php if ($see_all_text) : ?>
					<?php echo $see_all_text; ?>
				<?php else : ?>
					<?php echo __('See all our plans', 'subscribe-pro'); ?>
				<?php endif; ?>
			</a>
			<?php endif; ?>		
					
	<?php
		wp_reset_postdata();
		endif;
		echo $args['after_widget'];

	}
	
}